==> org-lsst-sal-camera-2.6.2-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket5_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket5_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus5_clampState;

  private final int clampxminus5_filterPositionSensorValue;

  private final int clampxminus5_filterPresenceOffset2;

  private final String clampxminus5_filterPresenceStatus;

  private final int clampxminus5_lockSensorOffset1;

  private final int clampxminus5_lockSensorValue;

  private final String clampxminus5_lockStatus;

  private final String clampxplus5_clampState;

  private final int clampxplus5_filterPositionSensorValue;

  private final int clampxplus5_filterPresenceOffset2;

  private final String clampxplus5_filterPresenceStatus;

  private final int clampxplus5_lockSensorOffset1;

  private final int clampxplus5_lockSensorValue;

  private final String clampxplus5_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final int filterID;

  private final String ioStatus;

  public Fcs_Carousel_Socket5_TrendingTelemetry(boolean atStandby, String clampxminus5_clampState,
      int clampxminus5_filterPositionSensorValue, int clampxminus5_filterPresenceOffset2,
      String clampxminus5_filterPresenceStatus, int clampxminus5_lockSensorOffset1,
      int clampxminus5_lockSensorValue, String clampxminus5_lockStatus,
      String clampxplus5_clampState, int clampxplus5_filterPositionSensorValue,
      int clampxplus5_filterPresenceOffset2, String clampxplus5_filterPresenceStatus,
      int clampxplus5_lockSensorOffset1, int clampxplus5_lockSensorValue,
      String clampxplus5_lockStatus, String clampsState, boolean empty, int filterID,
      String ioStatus) {
    this.atStandby = atStandby;
    this.clampxminus5_clampState = clampxminus5_clampState;
    this.clampxminus5_filterPositionSensorValue = clampxminus5_filterPositionSensorValue;
    this.clampxminus5_filterPresenceOffset2 = clampxminus5_filterPresenceOffset2;
    this.clampxminus5_filterPresenceStatus = clampxminus5_filterPresenceStatus;
    this.clampxminus5_lockSensorOffset1 = clampxminus5_lockSensorOffset1;
    this.clampxminus5_lockSensorValue = clampxminus5_lockSensorValue;
    this.clampxminus5_lockStatus = clampxminus5_lockStatus;
    this.clampxplus5_clampState = clampxplus5_clampState;
    this.clampxplus5_filterPositionSensorValue = clampxplus5_filterPositionSensorValue;
    this.clampxplus5_filterPresenceOffset2 = clampxplus5_filterPresenceOffset2;
    this.clampxplus5_filterPresenceStatus = clampxplus5_filterPresenceStatus;
    this.clampxplus5_lockSensorOffset1 = clampxplus5_lockSensorOffset1;
    this.clampxplus5_lockSensorValue = clampxplus5_lockSensorValue;
    this.clampxplus5_lockStatus = clampxplus5_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterID = filterID;
    this.ioStatus = ioStatus;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus5_clampState() {
    return clampxminus5_clampState;
  }

  public int getClampxminus5_filterPositionSensorValue() {
    return clampxminus5_filterPositionSensorValue;
  }

  public int getClampxminus5_filterPresenceOffset2() {
    return clampxminus5_filterPresenceOffset2;
  }

  public String getClampxminus5_filterPresenceStatus() {
    return clampxminus5_filterPresenceStatus;
  }

  public int getClampxminus5_lockSensorOffset1() {
    return clampxminus5_lockSensorOffset1;
  }

  public int getClampxminus5_lockSensorValue() {
    return clampxminus5_lockSensorValue;
  }

  public String getClampxminus5_lockStatus() {
    return clampxminus5_lockStatus;
  }

  public String getClampxplus5_clampState() {
    return clampxplus5_clampState;
  }

  public int getClampxplus5_filterPositionSensorValue() {
    return clampxplus5_filterPositionSensorValue;
  }

  public int getClampxplus5_filterPresenceOffset2() {
    return clampxplus5_filterPresenceOffset2;
  }

  public String getClampxplus5_filterPresenceStatus() {
    return clampxplus5_filterPresenceStatus;
  }

  public int getClampxplus5_lockSensorOffset1() {
    return clampxplus5_lockSensorOffset1;
  }

  public int getClampxplus5_lockSensorValue() {
    return clampxplus5_lockSensorValue;
  }

  public String getClampxplus5_lockStatus() {
    return clampxplus5_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public int getFilterID() {
    return filterID;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket5_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus5_clampState=" + clampxminus5_clampState +
        ", clampxminus5_filterPositionSensorValue=" + clampxminus5_filterPositionSensorValue +
        ", clampxminus5_filterPresenceOffset2=" + clampxminus5_filterPresenceOffset2 +
        ", clampxminus5_filterPresenceStatus=" + clampxminus5_filterPresenceStatus +
        ", clampxminus5_lockSensorOffset1=" + clampxminus5_lockSensorOffset1 +
        ", clampxminus5_lockSensorValue=" + clampxminus5_lockSensorValue +
        ", clampxminus5_lockStatus=" + clampxminus5_lockStatus +
        ", clampxplus5_clampState=" + clampxplus5_clampState +
        ", clampxplus5_filterPositionSensorValue=" + clampxplus5_filterPositionSensorValue +
        ", clampxplus5_filterPresenceOffset2=" + clampxplus5_filterPresenceOffset2 +
        ", clampxplus5_filterPresenceStatus=" + clampxplus5_filterPresenceStatus +
        ", clampxplus5_lockSensorOffset1=" + clampxplus5_lockSensorOffset1 +
        ", clampxplus5_lockSensorValue=" + clampxplus5_lockSensorValue +
        ", clampxplus5_lockStatus=" + clampxplus5_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterID=" + filterID +", ioStatus=" + ioStatus +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus5_clampState;

    private int clampxminus5_filterPositionSensorValue;

    private int clampxminus5_filterPresenceOffset2;

    private String clampxminus5_filterPresenceStatus;

    private int clampxminus5_lockSensorOffset1;

    private int clampxminus5_lockSensorValue;

    private String clampxminus5_lockStatus;

    private String clampxplus5_clampState;

    private int clampxplus5_filterPositionSensorValue;

    private int clampxplus5_filterPresenceOffset2;

    private String clampxplus5_filterPresenceStatus;

    private int clampxplus5_lockSensorOffset1;

    private int clampxplus5_lockSensorValue;

    private String clampxplus5_lockStatus;

    private String clampsState;

    private boolean empty;

    private int filterID;

    private String ioStatus;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus5_clampState(String clampxminus5_clampState) {
      this.clampxminus5_clampState = clampxminus5_clampState;
      return this;
    }

    public Builder clampxminus5_filterPositionSensorValue(
        int clampxminus5_filterPositionSensorValue) {
      this.clampxminus5_filterPositionSensorValue = clampxminus5_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus5_filterPresenceOffset2(int clampxminus5_filterPresenceOffset2) {
      this.clampxminus5_filterPresenceOffset2 = clampxminus5_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus5_filterPresenceStatus(String clampxminus5_filterPresenceStatus) {
      this.clampxminus5_filterPresenceStatus = clampxminus5_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus5_lockSensorOffset1(int clampxminus5_lockSensorOffset1) {
      this.clampxminus5_lockSensorOffset1 = clampxminus5_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus5_lockSensorValue(int clampxminus5_lockSensorValue) {
      this.clampxminus5_lockSensorValue = clampxminus5_lockSensorValue;
      return this;
    }

    public Builder clampxminus5_lockStatus(String clampxminus5_lockStatus) {
      this.clampxminus5_lockStatus = clampxminus5_lockStatus;
      return this;
    }

    public Builder clampxplus5_clampState(String clampxplus5_clampState) {
      this.clampxplus5_clampState = clampxplus5_clampState;
      return this;
    }

    public Builder clampxplus5_filterPositionSensorValue(
        int clampxplus5_filterPositionSensorValue) {
      this.clampxplus5_filterPositionSensorValue = clampxplus5_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus5_filterPresenceOffset2(int clampxplus5_filterPresenceOffset2) {
      this.clampxplus5_filterPresenceOffset2 = clampxplus5_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus5_filterPresenceStatus(String clampxplus5_filterPresenceStatus) {
      this.clampxplus5_filterPresenceStatus = clampxplus5_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus5_lockSensorOffset1(int clampxplus5_lockSensorOffset1) {
      this.clampxplus5_lockSensorOffset1 = clampxplus5_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus5_lockSensorValue(int clampxplus5_lockSensorValue) {
      this.clampxplus5_lockSensorValue = clampxplus5_lockSensorValue;
      return this;
    }

    public Builder clampxplus5_lockStatus(String clampxplus5_lockStatus) {
      this.clampxplus5_lockStatus = clampxplus5_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterID(int filterID) {
      this.filterID = filterID;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Fcs_Carousel_Socket5_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket5_TrendingTelemetry(atStandby, clampxminus5_clampState, clampxminus5_filterPositionSensorValue, clampxminus5_filterPresenceOffset2, clampxminus5_filterPresenceStatus, clampxminus5_lockSensorOffset1, clampxminus5_lockSensorValue, clampxminus5_lockStatus, clampxplus5_clampState, clampxplus5_filterPositionSensorValue, clampxplus5_filterPresenceOffset2, clampxplus5_filterPresenceStatus, clampxplus5_lockSensorOffset1, clampxplus5_lockSensorValue, clampxplus5_lockStatus, clampsState, empty, filterID, ioStatus);
    }
  }
}

==> org-lsst-sal-camera-3.0.1-sources.jar: org/lsst/sal/camera/telemetry/Fcs_Carousel_Socket5_TrendingTelemetry.java <==
package org.lsst.sal.camera.telemetry;

import org.lsst.sal.camera.CameraTelemetry;

public class Fcs_Carousel_Socket5_TrendingTelemetry extends CameraTelemetry {
  private final boolean atStandby;

  private final String clampxminus5_clampState;

  private final int clampxminus5_filterPositionSensorValue;

  private final int clampxminus5_filterPresenceOffset2;

  private final String clampxminus5_filterPresenceStatus;

  private final int clampxminus5_lockSensorOffset1;

  private final int clampxminus5_lockSensorValue;

  private final String clampxminus5_lockStatus;

  private final String clampxplus5_clampState;

  private final int clampxplus5_filterPositionSensorValue;

  private final int clampxplus5_filterPresenceOffset2;

  private final String clampxplus5_filterPresenceStatus;

  private final int clampxplus5_lockSensorOffset1;

  private final int clampxplus5_lockSensorValue;

  private final String clampxplus5_lockStatus;

  private final String clampsState;

  private final boolean empty;

  private final String filterName;

  private final String ioStatus;

  private final int socketID;

  public Fcs_Carousel_Socket5_TrendingTelemetry(boolean atStandby, String clampxminus5_clampState,
      int clampxminus5_filterPositionSensorValue, int clampxminus5_filterPresenceOffset2,
      String clampxminus5_filterPresenceStatus, int clampxminus5_lockSensorOffset1,
      int clampxminus5_lockSensorValue, String clampxminus5_lockStatus,
      String clampxplus5_clampState, int clampxplus5_filterPositionSensorValue,
      int clampxplus5_filterPresenceOffset2, String clampxplus5_filterPresenceStatus,
      int clampxplus5_lockSensorOffset1, int clampxplus5_lockSensorValue,
      String clampxplus5_lockStatus, String clampsState, boolean empty, String filterName,
      String ioStatus, int socketID) {
    this.atStandby = atStandby;
    this.clampxminus5_clampState = clampxminus5_clampState;
    this.clampxminus5_filterPositionSensorValue = clampxminus5_filterPositionSensorValue;
    this.clampxminus5_filterPresenceOffset2 = clampxminus5_filterPresenceOffset2;
    this.clampxminus5_filterPresenceStatus = clampxminus5_filterPresenceStatus;
    this.clampxminus5_lockSensorOffset1 = clampxminus5_lockSensorOffset1;
    this.clampxminus5_lockSensorValue = clampxminus5_lockSensorValue;
    this.clampxminus5_lockStatus = clampxminus5_lockStatus;
    this.clampxplus5_clampState = clampxplus5_clampState;
    this.clampxplus5_filterPositionSensorValue = clampxplus5_filterPositionSensorValue;
    this.clampxplus5_filterPresenceOffset2 = clampxplus5_filterPresenceOffset2;
    this.clampxplus5_filterPresenceStatus = clampxplus5_filterPresenceStatus;
    this.clampxplus5_lockSensorOffset1 = clampxplus5_lockSensorOffset1;
    this.clampxplus5_lockSensorValue = clampxplus5_lockSensorValue;
    this.clampxplus5_lockStatus = clampxplus5_lockStatus;
    this.clampsState = clampsState;
    this.empty = empty;
    this.filterName = filterName;
    this.ioStatus = ioStatus;
    this.socketID = socketID;
  }

  public boolean isAtStandby() {
    return atStandby;
  }

  public String getClampxminus5_clampState() {
    return clampxminus5_clampState;
  }

  public int getClampxminus5_filterPositionSensorValue() {
    return clampxminus5_filterPositionSensorValue;
  }

  public int getClampxminus5_filterPresenceOffset2() {
    return clampxminus5_filterPresenceOffset2;
  }

  public String getClampxminus5_filterPresenceStatus() {
    return clampxminus5_filterPresenceStatus;
  }

  public int getClampxminus5_lockSensorOffset1() {
    return clampxminus5_lockSensorOffset1;
  }

  public int getClampxminus5_lockSensorValue() {
    return clampxminus5_lockSensorValue;
  }

  public String getClampxminus5_lockStatus() {
    return clampxminus5_lockStatus;
  }

  public String getClampxplus5_clampState() {
    return clampxplus5_clampState;
  }

  public int getClampxplus5_filterPositionSensorValue() {
    return clampxplus5_filterPositionSensorValue;
  }

  public int getClampxplus5_filterPresenceOffset2() {
    return clampxplus5_filterPresenceOffset2;
  }

  public String getClampxplus5_filterPresenceStatus() {
    return clampxplus5_filterPresenceStatus;
  }

  public int getClampxplus5_lockSensorOffset1() {
    return clampxplus5_lockSensorOffset1;
  }

  public int getClampxplus5_lockSensorValue() {
    return clampxplus5_lockSensorValue;
  }

  public String getClampxplus5_lockStatus() {
    return clampxplus5_lockStatus;
  }

  public String getClampsState() {
    return clampsState;
  }

  public boolean isEmpty() {
    return empty;
  }

  public String getFilterName() {
    return filterName;
  }

  public String getIoStatus() {
    return ioStatus;
  }

  public int getSocketID() {
    return socketID;
  }

  @Override
  public String toString() {
    return "Fcs_Carousel_Socket5_TrendingTelemetry{" + "atStandby=" + atStandby +
        ", clampxminus5_clampState=" + clampxminus5_clampState +
        ", clampxminus5_filterPositionSensorValue=" + clampxminus5_filterPositionSensorValue +
        ", clampxminus5_filterPresenceOffset2=" + clampxminus5_filterPresenceOffset2 +
        ", clampxminus5_filterPresenceStatus=" + clampxminus5_filterPresenceStatus +
        ", clampxminus5_lockSensorOffset1=" + clampxminus5_lockSensorOffset1 +
        ", clampxminus5_lockSensorValue=" + clampxminus5_lockSensorValue +
        ", clampxminus5_lockStatus=" + clampxminus5_lockStatus +
        ", clampxplus5_clampState=" + clampxplus5_clampState +
        ", clampxplus5_filterPositionSensorValue=" + clampxplus5_filterPositionSensorValue +
        ", clampxplus5_filterPresenceOffset2=" + clampxplus5_filterPresenceOffset2 +
        ", clampxplus5_filterPresenceStatus=" + clampxplus5_filterPresenceStatus +
        ", clampxplus5_lockSensorOffset1=" + clampxplus5_lockSensorOffset1 +
        ", clampxplus5_lockSensorValue=" + clampxplus5_lockSensorValue +
        ", clampxplus5_lockStatus=" + clampxplus5_lockStatus +", clampsState=" + clampsState +
        ", empty=" + empty +", filterName=" + filterName +", ioStatus=" + ioStatus +
        ", socketID=" + socketID +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private boolean atStandby;

    private String clampxminus5_clampState;

    private int clampxminus5_filterPositionSensorValue;

    private int clampxminus5_filterPresenceOffset2;

    private String clampxminus5_filterPresenceStatus;

    private int clampxminus5_lockSensorOffset1;

    private int clampxminus5_lockSensorValue;

    private String clampxminus5_lockStatus;

    private String clampxplus5_clampState;

    private int clampxplus5_filterPositionSensorValue;

    private int clampxplus5_filterPresenceOffset2;

    private String clampxplus5_filterPresenceStatus;

    private int clampxplus5_lockSensorOffset1;

    private int clampxplus5_lockSensorValue;

    private String clampxplus5_lockStatus;

    private String clampsState;

    private boolean empty;

    private String filterName;

    private String ioStatus;

    private int socketID;

    private Builder() {
    }

    public Builder atStandby(boolean atStandby) {
      this.atStandby = atStandby;
      return this;
    }

    public Builder clampxminus5_clampState(String clampxminus5_clampState) {
      this.clampxminus5_clampState = clampxminus5_clampState;
      return this;
    }

    public Builder clampxminus5_filterPositionSensorValue(
        int clampxminus5_filterPositionSensorValue) {
      this.clampxminus5_filterPositionSensorValue = clampxminus5_filterPositionSensorValue;
      return this;
    }

    public Builder clampxminus5_filterPresenceOffset2(int clampxminus5_filterPresenceOffset2) {
      this.clampxminus5_filterPresenceOffset2 = clampxminus5_filterPresenceOffset2;
      return this;
    }

    public Builder clampxminus5_filterPresenceStatus(String clampxminus5_filterPresenceStatus) {
      this.clampxminus5_filterPresenceStatus = clampxminus5_filterPresenceStatus;
      return this;
    }

    public Builder clampxminus5_lockSensorOffset1(int clampxminus5_lockSensorOffset1) {
      this.clampxminus5_lockSensorOffset1 = clampxminus5_lockSensorOffset1;
      return this;
    }

    public Builder clampxminus5_lockSensorValue(int clampxminus5_lockSensorValue) {
      this.clampxminus5_lockSensorValue = clampxminus5_lockSensorValue;
      return this;
    }

    public Builder clampxminus5_lockStatus(String clampxminus5_lockStatus) {
      this.clampxminus5_lockStatus = clampxminus5_lockStatus;
      return this;
    }

    public Builder clampxplus5_clampState(String clampxplus5_clampState) {
      this.clampxplus5_clampState = clampxplus5_clampState;
      return this;
    }

    public Builder clampxplus5_filterPositionSensorValue(
        int clampxplus5_filterPositionSensorValue) {
      this.clampxplus5_filterPositionSensorValue = clampxplus5_filterPositionSensorValue;
      return this;
    }

    public Builder clampxplus5_filterPresenceOffset2(int clampxplus5_filterPresenceOffset2) {
      this.clampxplus5_filterPresenceOffset2 = clampxplus5_filterPresenceOffset2;
      return this;
    }

    public Builder clampxplus5_filterPresenceStatus(String clampxplus5_filterPresenceStatus) {
      this.clampxplus5_filterPresenceStatus = clampxplus5_filterPresenceStatus;
      return this;
    }

    public Builder clampxplus5_lockSensorOffset1(int clampxplus5_lockSensorOffset1) {
      this.clampxplus5_lockSensorOffset1 = clampxplus5_lockSensorOffset1;
      return this;
    }

    public Builder clampxplus5_lockSensorValue(int clampxplus5_lockSensorValue) {
      this.clampxplus5_lockSensorValue = clampxplus5_lockSensorValue;
      return this;
    }

    public Builder clampxplus5_lockStatus(String clampxplus5_lockStatus) {
      this.clampxplus5_lockStatus = clampxplus5_lockStatus;
      return this;
    }

    public Builder clampsState(String clampsState) {
      this.clampsState = clampsState;
      return this;
    }

    public Builder empty(boolean empty) {
      this.empty = empty;
      return this;
    }

    public Builder filterName(String filterName) {
      this.filterName = filterName;
      return this;
    }

    public Builder ioStatus(String ioStatus) {
      this.ioStatus = ioStatus;
      return this;
    }

    public Builder socketID(int socketID) {
      this.socketID = socketID;
      return this;
    }

    public Fcs_Carousel_Socket5_TrendingTelemetry build() {
      return new Fcs_Carousel_Socket5_TrendingTelemetry(atStandby, clampxminus5_clampState, clampxminus5_filterPositionSensorValue, clampxminus5_filterPresenceOffset2, clampxminus5_filterPresenceStatus, clampxminus5_lockSensorOffset1, clampxminus5_lockSensorValue, clampxminus5_lockStatus, clampxplus5_clampState, clampxplus5_filterPositionSensorValue, clampxplus5_filterPresenceOffset2, clampxplus5_filterPresenceStatus, clampxplus5_lockSensorOffset1, clampxplus5_lockSensorValue, clampxplus5_lockStatus, clampsState, empty, filterName, ioStatus, socketID);
    }
  }
}
